@@ -6,6 +6,9 @@ function(g,batches){
   if(length(levels(batches))<1.5){stop("batches has to be a factor with at least two levels")}
   if(length(batches)!=ncol(g)){stop("batches has not the same length as ncol(g)")}
   if (any(table(batches)<1.5)){stop("a level of batches has one or zero counts")}
+  isna<-which(is.na(batches))
+  if (length(isna)>0) {warning(paste("Samples",toString(isna),"will not be adjusted because of NAs in batches"))   }
+ 
   
   gafter<-g
   gafter[]<-NA
